info property
info is the account info which is represented by BaseAccount.
Implementation
@$pb.TagNumber(1)
$48.BaseAccount get info => $_getN(0);
Implementation
@$pb.TagNumber(1)
set info($48.BaseAccount v) { setField(1, v); }
info is the account info which is represented by BaseAccount.
@$pb.TagNumber(1)
$48.BaseAccount get info => $_getN(0);
@$pb.TagNumber(1)
set info($48.BaseAccount v) { setField(1, v); }