short property
short is the short description shown in the 'help' output.
Implementation
@$pb.TagNumber(4)
$core.String get short => $_getSZ(3);
Implementation
@$pb.TagNumber(4)
set short($core.String v) { $_setString(3, v); }
short is the short description shown in the 'help' output.
@$pb.TagNumber(4)
$core.String get short => $_getSZ(3);
@$pb.TagNumber(4)
set short($core.String v) { $_setString(3, v); }