tx property
tx provides metadata information regarding how to send transactions to the given application
Implementation
@$pb.TagNumber(6)
TxDescriptor get tx => $_getN(5);
Implementation
@$pb.TagNumber(6)
set tx(TxDescriptor v) { setField(6, v); }
tx provides metadata information regarding how to send transactions to the given application
@$pb.TagNumber(6)
TxDescriptor get tx => $_getN(5);
@$pb.TagNumber(6)
set tx(TxDescriptor v) { setField(6, v); }