address property
address is the account address of the group policy.
Implementation
@$pb.TagNumber(1)
$core.String get address => $_getSZ(0);
Implementation
@$pb.TagNumber(1)
set address($core.String v) { $_setString(0, v); }
address is the account address of the group policy.
@$pb.TagNumber(1)
$core.String get address => $_getSZ(0);
@$pb.TagNumber(1)
set address($core.String v) { $_setString(0, v); }