payer property
if unset, the first signer is responsible for paying the fees. If set, the specified account must pay the fees. the payer must be a tx signer (and thus have signed this field in AuthInfo). setting this field does not change the ordering of required signers for the transaction.
Implementation
@$pb.TagNumber(3)
$core.String get payer => $_getSZ(2);
Implementation
@$pb.TagNumber(3)
set payer($core.String v) { $_setString(2, v); }